var class_ogre_1_1_light =
[
    [ "LightTypes", "class_ogre_1_1_light.html#af20fe2bb87447be7a9a5327c65dee345", [
      [ "LT_POINT", "class_ogre_1_1_light.html#af20fe2bb87447be7a9a5327c65dee345a0d59bfdcfeb338dbfe06e2e2999e752f", null ],
      [ "LT_DIRECTIONAL", "class_ogre_1_1_light.html#af20fe2bb87447be7a9a5327c65dee345a4c5582d28848ce40c2b652488494b4a3", null ],
      [ "LT_SPOTLIGHT", "class_ogre_1_1_light.html#af20fe2bb87447be7a9a5327c65dee345a8fc40a1ccfb026944417ef92b7ddaefe", null ],
      [ "LT_RECTLIGHT", "class_ogre_1_1_light.html#af20fe2bb87447be7a9a5327c65dee345aca0a6bc4ab27bc276096bc9b4a4add74", null ]
    ] ],
    [ "Light", "class_ogre_1_1_light.html#ad2e58022048b39881379298e30fa2765", null ],
    [ "Light", "class_ogre_1_1_light.html#acee7830214ec1660dc13796f6ca99e36", null ],
    [ "~Light", "class_ogre_1_1_light.html#afbfeabb7d5503e571528fc0d365dc80a", null ],
    [ "_calcTempSquareDist", "class_ogre_1_1_light.html#a6b0962ead2b2a699af0d2b564450e5ae", null ],
    [ "setType", "class_ogre_1_1_light.html#a6019f7fa89624e35316ba444e519d8f8", null ],
    [ "getType", "class_ogre_1_1_light.html#a8ef572fd5d20b366328cbdb0eb71b4a0", null ],
    [ "setDiffuseColour", "class_ogre_1_1_light.html#ae7ade1a5befac759d77fa3fe9a399e5c", null ],
    [ "setDiffuseColour", "class_ogre_1_1_light.html#a1cab92f6d67cb87f2ca99d04e897093c", null ],
    [ "getDiffuseColour", "class_ogre_1_1_light.html#aff98b9ed31a64b4801740ff400ac8e85", null ],
    [ "setSpecularColour", "class_ogre_1_1_light.html#a8ae9c19d6fd9d0d3a961225abd29126e", null ],
    [ "setSpecularColour", "class_ogre_1_1_light.html#a614988755dcedf910f7df90fafe6158e", null ],
    [ "getSpecularColour", "class_ogre_1_1_light.html#a6d84ea02ea0ad4f27fb1c2aeebcbc6e8", null ],
    [ "setAttenuation", "class_ogre_1_1_light.html#a43f763d809bc7da9a85fec15f57380f4", null ],
    [ "getAttenuationRange", "class_ogre_1_1_light.html#a32e5a972d801c2b806b2610278df0644", null ],
    [ "getAttenuationConstant", "class_ogre_1_1_light.html#ad2596d3f1a8650287af20ec75040626d", null ],
    [ "getAttenuationLinear", "class_ogre_1_1_light.html#ab8094b8dd552877204d4734a33aab315", null ],
    [ "getAttenuationQuadric", "class_ogre_1_1_light.html#ae33eeb846eb28d51a7736b3e40f2f7b9", null ],
    [ "getAttenuation", "class_ogre_1_1_light.html#ade9916c969963ad75562a127610222a1", null ],
    [ "setPosition", "class_ogre_1_1_light.html#af45236b1551783320d75c662abdf9b1b", null ],
    [ "setPosition", "class_ogre_1_1_light.html#ab6b95e8fe205428797eb4cb40c811780", null ],
    [ "getPosition", "class_ogre_1_1_light.html#a1156525adbbb29e585f921a83ad42fa2", null ],
    [ "setDirection", "class_ogre_1_1_light.html#aa9c6df55eafb28a2a0bab287bc9596f7", null ],
    [ "setDirection", "class_ogre_1_1_light.html#a1659111f4eb55f3b3227e87c8bfce8d9", null ],
    [ "getDirection", "class_ogre_1_1_light.html#aa41bd29b2f37800f618cdb1eb73ef2c7", null ],
    [ "_notifyAttached", "class_ogre_1_1_light.html#a7986250539b65b5c871c274605cb4ca9", null ],
    [ "_notifyMoved", "class_ogre_1_1_light.html#a07d89683bfadf75cce21944e10dda0fb", null ],
    [ "setSpotlightRange", "class_ogre_1_1_light.html#a8ef06bd9c2e7113461c50c83c5f09fe9", null ],
    [ "getSpotlightInnerAngle", "class_ogre_1_1_light.html#a55cda420f991dcb9cfc8ccb56fc227b0", null ],
    [ "getSpotlightOuterAngle", "class_ogre_1_1_light.html#a20ef8a0dc69223d29971f00a90bf5b35", null ],
    [ "getSpotlightFalloff", "class_ogre_1_1_light.html#a6372e140e51cab8406adcffefe46a9f5", null ],
    [ "setSpotlightInnerAngle", "class_ogre_1_1_light.html#ad9adeeb164ff515099236e2e8fb0c850", null ],
    [ "setSpotlightOuterAngle", "class_ogre_1_1_light.html#ad4d52d64dca4df8a930a2401028f73ff", null ],
    [ "setSpotlightFalloff", "class_ogre_1_1_light.html#aec895d9f784ea062ce69c823737229c5", null ],
    [ "setSpotlightNearClipDistance", "class_ogre_1_1_light.html#aead9fea5c5d5869387d88869d0132cad", null ],
    [ "getSpotlightNearClipDistance", "class_ogre_1_1_light.html#ace79ed42960f5f2860b02bc408fbd767", null ],
    [ "setSourceSize", "class_ogre_1_1_light.html#adab100d5c8d5f4024f377fe20aebe8f2", null ],
    [ "getSourceSize", "class_ogre_1_1_light.html#ad03ff3840b97c737445128af9092ccc7", null ],
    [ "getDerivedSourceHalfWidth", "class_ogre_1_1_light.html#a34ce016cfa80713aabfec6c6e560d09a", null ],
    [ "getDerivedSourceHalfHeight", "class_ogre_1_1_light.html#a7f6a21c028c1623c9e16654da7d1c95c", null ],
    [ "setPowerScale", "class_ogre_1_1_light.html#a8588796e58389701c22fb8e5c62a080e", null ],
    [ "getPowerScale", "class_ogre_1_1_light.html#aaa6e49d21586b363c4d40a87407be38b", null ],
    [ "getBoundingRadius", "class_ogre_1_1_light.html#ad4a18c8fa6f5bfb38aba27dcbb8a2574", null ],
    [ "getBoundingBox", "class_ogre_1_1_light.html#ac055941546b1f7198952a833dfc675ae", null ],
    [ "_updateRenderQueue", "class_ogre_1_1_light.html#aff8c359ab9a11edca40236e45a7e39d0", null ],
    [ "getMovableType", "class_ogre_1_1_light.html#a62b19c68359eefb19d826160046a21e4", null ],
    [ "getDerivedPosition", "class_ogre_1_1_light.html#a3696c6673ab5951f0456b6b1a21e19ff", null ],
    [ "getDerivedDirection", "class_ogre_1_1_light.html#ad36544a14b5c9c0c2fff82e5a94abdf8", null ],
    [ "setVisible", "class_ogre_1_1_light.html#a264a43fc2cf02093736eae60316dda8e", null ],
    [ "getAs4DVector", "class_ogre_1_1_light.html#a052612372ad31e661d14fc4c3f83c5d2", null ],
    [ "_getNearClipVolume", "class_ogre_1_1_light.html#adae366516f078c422412f45778753516", null ],
    [ "_getFrustumClipVolumes", "class_ogre_1_1_light.html#a93ac8bb5fd365c2469c96db4b676a955", null ],
    [ "getTypeFlags", "class_ogre_1_1_light.html#a0cfffdce70400c39919f6625647a4c98", null ],
    [ "createAnimableValue", "class_ogre_1_1_light.html#a1a0671d05e0dcde78bb636e84bb13274", null ],
    [ "setCustomShadowCameraSetup", "class_ogre_1_1_light.html#a4a6f664fade2ac14d1ed5910b0d1a21a", null ],
    [ "resetCustomShadowCameraSetup", "class_ogre_1_1_light.html#a8dfbfef136e815bd6c8d2850b5364c44", null ],
    [ "getCustomShadowCameraSetup", "class_ogre_1_1_light.html#ada3b24400adba1e04a230b75ecb494bc", null ],
    [ "visitRenderables", "class_ogre_1_1_light.html#aadf873224d8b20e3a5a1a7a3db8083d9", null ],
    [ "_getIndexInFrame", "class_ogre_1_1_light.html#a3987443f1bfe5c6ada7e7688e7c221bc", null ],
    [ "_notifyIndexInFrame", "class_ogre_1_1_light.html#a8be55b8ecc3c79532711429fc8a5d36a", null ],
    [ "setShadowFarDistance", "class_ogre_1_1_light.html#ad2db241677e9fd1d48a3c97abeadfe07", null ],
    [ "resetShadowFarDistance", "class_ogre_1_1_light.html#a0b335a53572a929e720e563b2f45b72c", null ],
    [ "getShadowFarDistance", "class_ogre_1_1_light.html#a63ea738c19ed36e7c0a160585095e9ef", null ],
    [ "getShadowFarDistanceSquared", "class_ogre_1_1_light.html#aaf2c5dfccfad0c80316c9d55ecc07e99", null ],
    [ "setShadowNearClipDistance", "class_ogre_1_1_light.html#a91a8c7867631ecda45eb934bfaf0aff1", null ],
    [ "getShadowNearClipDistance", "class_ogre_1_1_light.html#a6ffba71e5b797689b61ff0e285449491", null ],
    [ "_deriveShadowNearClipDistance", "class_ogre_1_1_light.html#a0a7c23a753bf2c7b1ded3b6b874a82a5", null ],
    [ "setShadowFarClipDistance", "class_ogre_1_1_light.html#aeb90ddb3515b7e3ac936367e40d49d20", null ],
    [ "getShadowFarClipDistance", "class_ogre_1_1_light.html#af3cd6abc354021078ce103eda3aa2b1a", null ],
    [ "_deriveShadowFarClipDistance", "class_ogre_1_1_light.html#a37e3831c612d5a238c3fc9961a6700a4", null ],
    [ "_deriveShadowFarClipDistance", "class_ogre_1_1_light.html#af49bbb5413e184b1e2c6c0fece911747", null ],
    [ "_setCameraRelative", "class_ogre_1_1_light.html#ad353bf8b10bd5da88f598c137081dda1", null ],
    [ "setCustomParameter", "class_ogre_1_1_light.html#a6c7a27f0850dabeb1e9a6f568f7dba1a", null ],
    [ "getCustomParameter", "class_ogre_1_1_light.html#aa654189e8307f6d173bdc657c4005674", null ],
    [ "_updateCustomGpuParameter", "class_ogre_1_1_light.html#a66a5e07e85c60958f6a22590b6bed9a5", null ],
    [ "isInLightRange", "class_ogre_1_1_light.html#a690b8626f9bc29d87dce0ac536276bb1", null ],
    [ "isInLightRange", "class_ogre_1_1_light.html#a555aaeda1762a4820baf9648a2189b85", null ],
    [ "tempSquareDist", "class_ogre_1_1_light.html#ae3e2e4e50055bf99fd923ffa4f539f7d", null ]
];